Tools
=====

Robot Management
---------------
.. automodule:: figaroh.tools.robot
   :members:
   :undoc-members:
   :show-inheritance:

Enhanced Regressor Builder
-------------------------
.. automodule:: figaroh.tools.regressor
   :members:
   :undoc-members:
   :show-inheritance:

Robot Visualization
------------------
.. automodule:: figaroh.tools.robotvisualization
   :members:
   :undoc-members:
   :show-inheritance:

Robot Collisions
-----------------
.. automodule:: figaroh.tools.robotcollisions
   :members:
   :undoc-members:
   :show-inheritance:

QR Decomposition
---------------
.. automodule:: figaroh.tools.qrdecomposition
   :members:
   :undoc-members:
   :show-inheritance:

Robot IPOPT
----------
.. automodule:: figaroh.tools.robotipopt
   :members:
   :undoc-members:
   :show-inheritance:

Random Data Generation
---------------------
.. automodule:: figaroh.tools.randomdata
   :members:
   :undoc-members:
   :show-inheritance:
